# Transport research international documentation (TRID)

## search

### DB search

Download search results and store in `data/search/` directory. API-access not yet available.

## Links

- [TRID](https://trid.trb.org/)
